# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsDeletionData
from ..models import ModelsDeletionStatus
from ..models import ModelsListDeletionDataResponse
from ..models import ModelsRequestDeleteResponse
from ..models import ResponseError

from ..operations.data_deletion import AdminCancelUserAccountDeletionRequest
from ..operations.data_deletion import AdminGetListDeletionDataRequest
from ..operations.data_deletion import AdminGetUserAccountDeletionRequest
from ..operations.data_deletion import AdminSubmitUserAccountDeletionRequest
from ..operations.data_deletion import PublicCancelUserAccountDeletionRequest
from ..operations.data_deletion import PublicGetUserAccountDeletionStatus
from ..operations.data_deletion import PublicSubmitUserAccountDeletionRequest


@same_doc_as(AdminCancelUserAccountDeletionRequest)
def admin_cancel_user_account_deletion_request(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCancelUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCancelUserAccountDeletionRequest)
async def admin_cancel_user_account_deletion_request_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCancelUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetListDeletionDataRequest)
def admin_get_list_deletion_data_request(
    after: Optional[str] = None,
    before: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    request_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetListDeletionDataRequest.create(
        after=after,
        before=before,
        limit=limit,
        offset=offset,
        request_date=request_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetListDeletionDataRequest)
async def admin_get_list_deletion_data_request_async(
    after: Optional[str] = None,
    before: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    request_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetListDeletionDataRequest.create(
        after=after,
        before=before,
        limit=limit,
        offset=offset,
        request_date=request_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetUserAccountDeletionRequest)
def admin_get_user_account_deletion_request(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetUserAccountDeletionRequest)
async def admin_get_user_account_deletion_request_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSubmitUserAccountDeletionRequest)
def admin_submit_user_account_deletion_request(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSubmitUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSubmitUserAccountDeletionRequest)
async def admin_submit_user_account_deletion_request_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSubmitUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicCancelUserAccountDeletionRequest)
def public_cancel_user_account_deletion_request(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCancelUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicCancelUserAccountDeletionRequest)
async def public_cancel_user_account_deletion_request_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCancelUserAccountDeletionRequest.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetUserAccountDeletionStatus)
def public_get_user_account_deletion_status(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserAccountDeletionStatus.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetUserAccountDeletionStatus)
async def public_get_user_account_deletion_status_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserAccountDeletionStatus.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicSubmitUserAccountDeletionRequest)
def public_submit_user_account_deletion_request(
    password: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSubmitUserAccountDeletionRequest.create(
        password=password,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicSubmitUserAccountDeletionRequest)
async def public_submit_user_account_deletion_request_async(
    password: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSubmitUserAccountDeletionRequest.create(
        password=password,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.17.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.time_limited_balance import TimeLimitedBalance


class StatusEnum(StrEnum):
    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"


class WalletInfo(Model):
    """Wallet info (WalletInfo)

    Properties:
        balance: (balance) REQUIRED int

        balance_origin: (balanceOrigin) REQUIRED str

        created_at: (createdAt) REQUIRED str

        currency_code: (currencyCode) REQUIRED str

        currency_symbol: (currencySymbol) REQUIRED str

        id_: (id) REQUIRED str

        namespace: (namespace) REQUIRED str

        status: (status) REQUIRED Union[str, StatusEnum]

        updated_at: (updatedAt) REQUIRED str

        user_id: (userId) REQUIRED str

        time_limited_balances: (timeLimitedBalances) OPTIONAL List[TimeLimitedBalance]

        total_permanent_balance: (totalPermanentBalance) OPTIONAL int

        total_time_limited_balance: (totalTimeLimitedBalance) OPTIONAL int
    """

    # region fields

    balance: int  # REQUIRED
    balance_origin: str  # REQUIRED
    created_at: str  # REQUIRED
    currency_code: str  # REQUIRED
    currency_symbol: str  # REQUIRED
    id_: str  # REQUIRED
    namespace: str  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    updated_at: str  # REQUIRED
    user_id: str  # REQUIRED
    time_limited_balances: List[TimeLimitedBalance]  # OPTIONAL
    total_permanent_balance: int  # OPTIONAL
    total_time_limited_balance: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_balance(self, value: int) -> WalletInfo:
        self.balance = value
        return self

    def with_balance_origin(self, value: str) -> WalletInfo:
        self.balance_origin = value
        return self

    def with_created_at(self, value: str) -> WalletInfo:
        self.created_at = value
        return self

    def with_currency_code(self, value: str) -> WalletInfo:
        self.currency_code = value
        return self

    def with_currency_symbol(self, value: str) -> WalletInfo:
        self.currency_symbol = value
        return self

    def with_id(self, value: str) -> WalletInfo:
        self.id_ = value
        return self

    def with_namespace(self, value: str) -> WalletInfo:
        self.namespace = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> WalletInfo:
        self.status = value
        return self

    def with_updated_at(self, value: str) -> WalletInfo:
        self.updated_at = value
        return self

    def with_user_id(self, value: str) -> WalletInfo:
        self.user_id = value
        return self

    def with_time_limited_balances(self, value: List[TimeLimitedBalance]) -> WalletInfo:
        self.time_limited_balances = value
        return self

    def with_total_permanent_balance(self, value: int) -> WalletInfo:
        self.total_permanent_balance = value
        return self

    def with_total_time_limited_balance(self, value: int) -> WalletInfo:
        self.total_time_limited_balance = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "balance"):
            result["balance"] = int(self.balance)
        elif include_empty:
            result["balance"] = 0
        if hasattr(self, "balance_origin"):
            result["balanceOrigin"] = str(self.balance_origin)
        elif include_empty:
            result["balanceOrigin"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "currency_code"):
            result["currencyCode"] = str(self.currency_code)
        elif include_empty:
            result["currencyCode"] = ""
        if hasattr(self, "currency_symbol"):
            result["currencySymbol"] = str(self.currency_symbol)
        elif include_empty:
            result["currencySymbol"] = ""
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "time_limited_balances"):
            result["timeLimitedBalances"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.time_limited_balances
            ]
        elif include_empty:
            result["timeLimitedBalances"] = []
        if hasattr(self, "total_permanent_balance"):
            result["totalPermanentBalance"] = int(self.total_permanent_balance)
        elif include_empty:
            result["totalPermanentBalance"] = 0
        if hasattr(self, "total_time_limited_balance"):
            result["totalTimeLimitedBalance"] = int(self.total_time_limited_balance)
        elif include_empty:
            result["totalTimeLimitedBalance"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        balance: int,
        balance_origin: str,
        created_at: str,
        currency_code: str,
        currency_symbol: str,
        id_: str,
        namespace: str,
        status: Union[str, StatusEnum],
        updated_at: str,
        user_id: str,
        time_limited_balances: Optional[List[TimeLimitedBalance]] = None,
        total_permanent_balance: Optional[int] = None,
        total_time_limited_balance: Optional[int] = None,
    ) -> WalletInfo:
        instance = cls()
        instance.balance = balance
        instance.balance_origin = balance_origin
        instance.created_at = created_at
        instance.currency_code = currency_code
        instance.currency_symbol = currency_symbol
        instance.id_ = id_
        instance.namespace = namespace
        instance.status = status
        instance.updated_at = updated_at
        instance.user_id = user_id
        if time_limited_balances is not None:
            instance.time_limited_balances = time_limited_balances
        if total_permanent_balance is not None:
            instance.total_permanent_balance = total_permanent_balance
        if total_time_limited_balance is not None:
            instance.total_time_limited_balance = total_time_limited_balance
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> WalletInfo:
        instance = cls()
        if not dict_:
            return instance
        if "balance" in dict_ and dict_["balance"] is not None:
            instance.balance = int(dict_["balance"])
        elif include_empty:
            instance.balance = 0
        if "balanceOrigin" in dict_ and dict_["balanceOrigin"] is not None:
            instance.balance_origin = str(dict_["balanceOrigin"])
        elif include_empty:
            instance.balance_origin = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "currencyCode" in dict_ and dict_["currencyCode"] is not None:
            instance.currency_code = str(dict_["currencyCode"])
        elif include_empty:
            instance.currency_code = ""
        if "currencySymbol" in dict_ and dict_["currencySymbol"] is not None:
            instance.currency_symbol = str(dict_["currencySymbol"])
        elif include_empty:
            instance.currency_symbol = ""
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "timeLimitedBalances" in dict_ and dict_["timeLimitedBalances"] is not None:
            instance.time_limited_balances = [
                TimeLimitedBalance.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["timeLimitedBalances"]
            ]
        elif include_empty:
            instance.time_limited_balances = []
        if (
            "totalPermanentBalance" in dict_
            and dict_["totalPermanentBalance"] is not None
        ):
            instance.total_permanent_balance = int(dict_["totalPermanentBalance"])
        elif include_empty:
            instance.total_permanent_balance = 0
        if (
            "totalTimeLimitedBalance" in dict_
            and dict_["totalTimeLimitedBalance"] is not None
        ):
            instance.total_time_limited_balance = int(dict_["totalTimeLimitedBalance"])
        elif include_empty:
            instance.total_time_limited_balance = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, WalletInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[WalletInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[WalletInfo, List[WalletInfo], Dict[Any, WalletInfo]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "balance": "balance",
            "balanceOrigin": "balance_origin",
            "createdAt": "created_at",
            "currencyCode": "currency_code",
            "currencySymbol": "currency_symbol",
            "id": "id_",
            "namespace": "namespace",
            "status": "status",
            "updatedAt": "updated_at",
            "userId": "user_id",
            "timeLimitedBalances": "time_limited_balances",
            "totalPermanentBalance": "total_permanent_balance",
            "totalTimeLimitedBalance": "total_time_limited_balance",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "balance": True,
            "balanceOrigin": True,
            "createdAt": True,
            "currencyCode": True,
            "currencySymbol": True,
            "id": True,
            "namespace": True,
            "status": True,
            "updatedAt": True,
            "userId": True,
            "timeLimitedBalances": False,
            "totalPermanentBalance": False,
            "totalTimeLimitedBalance": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "status": ["ACTIVE", "INACTIVE"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import AdyenConfig
from ..models import AliPayConfig
from ..models import CheckoutConfig
from ..models import ErrorEntity
from ..models import PayPalConfig
from ..models import PaymentMerchantConfigInfo
from ..models import PaymentProviderConfigEdit
from ..models import PaymentProviderConfigInfo
from ..models import PaymentProviderConfigPagingSlicedResult
from ..models import PaymentTaxConfigEdit
from ..models import PaymentTaxConfigInfo
from ..models import StripeConfig
from ..models import TestResult
from ..models import ValidationErrorEntity
from ..models import WxPayConfigRequest
from ..models import XsollaConfig
from ..models import XsollaPaywallConfigRequest

from ..operations.payment_config import CreatePaymentProviderConfig
from ..operations.payment_config import DebugMatchedPaymentMerchantConfig
from ..operations.payment_config import DebugMatchedPaymentProviderConfig
from ..operations.payment_config import DeletePaymentProviderConfig
from ..operations.payment_config import GetAggregatePaymentProviders
from ..operations.payment_config import GetPaymentMerchantConfig
from ..operations.payment_config import GetPaymentTaxConfig
from ..operations.payment_config import GetSpecialPaymentProviders
from ..operations.payment_config import QueryPaymentProviderConfig
from ..operations.payment_config import TestAdyenConfig
from ..operations.payment_config import TestAdyenConfigById
from ..operations.payment_config import TestAliPayConfig
from ..operations.payment_config import TestAliPayConfigById
from ..operations.payment_config import TestCheckoutConfig
from ..operations.payment_config import TestCheckoutConfigById
from ..operations.payment_config import TestPayPalConfig
from ..operations.payment_config import TestPayPalConfigById
from ..operations.payment_config import TestStripeConfig
from ..operations.payment_config import TestStripeConfigById
from ..operations.payment_config import TestWxPayConfig
from ..operations.payment_config import TestWxPayConfigById
from ..operations.payment_config import TestXsollaConfig
from ..operations.payment_config import TestXsollaConfigById
from ..operations.payment_config import UpdateAdyenConfig
from ..operations.payment_config import UpdateAliPayConfig
from ..operations.payment_config import UpdateCheckoutConfig
from ..operations.payment_config import UpdatePayPalConfig
from ..operations.payment_config import UpdatePaymentProviderConfig
from ..operations.payment_config import UpdatePaymentTaxConfig
from ..operations.payment_config import UpdateStripeConfig
from ..operations.payment_config import UpdateWxPayConfig
from ..operations.payment_config import UpdateWxPayConfigCert
from ..operations.payment_config import UpdateXsollaConfig
from ..operations.payment_config import UpdateXsollaUIConfig
from ..models import (
    PaymentProviderConfigEditAggregateEnum,
    PaymentProviderConfigEditSpecialsEnum,
)
from ..models import (
    PaymentProviderConfigInfoAggregateEnum,
    PaymentProviderConfigInfoSpecialsEnum,
)
from ..models import (
    XsollaPaywallConfigRequestDeviceEnum,
    XsollaPaywallConfigRequestSizeEnum,
    XsollaPaywallConfigRequestThemeEnum,
)


@same_doc_as(CreatePaymentProviderConfig)
def create_payment_provider_config(
    body: Optional[PaymentProviderConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreatePaymentProviderConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreatePaymentProviderConfig)
async def create_payment_provider_config_async(
    body: Optional[PaymentProviderConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreatePaymentProviderConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DebugMatchedPaymentMerchantConfig)
def debug_matched_payment_merchant_config(
    namespace: Optional[str] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = DebugMatchedPaymentMerchantConfig.create(
        namespace=namespace,
        region=region,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DebugMatchedPaymentMerchantConfig)
async def debug_matched_payment_merchant_config_async(
    namespace: Optional[str] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = DebugMatchedPaymentMerchantConfig.create(
        namespace=namespace,
        region=region,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DebugMatchedPaymentProviderConfig)
def debug_matched_payment_provider_config(
    namespace: Optional[str] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = DebugMatchedPaymentProviderConfig.create(
        namespace=namespace,
        region=region,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DebugMatchedPaymentProviderConfig)
async def debug_matched_payment_provider_config_async(
    namespace: Optional[str] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = DebugMatchedPaymentProviderConfig.create(
        namespace=namespace,
        region=region,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeletePaymentProviderConfig)
def delete_payment_provider_config(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = DeletePaymentProviderConfig.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeletePaymentProviderConfig)
async def delete_payment_provider_config_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = DeletePaymentProviderConfig.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAggregatePaymentProviders)
def get_aggregate_payment_providers(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetAggregatePaymentProviders.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAggregatePaymentProviders)
async def get_aggregate_payment_providers_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetAggregatePaymentProviders.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetPaymentMerchantConfig)
def get_payment_merchant_config(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetPaymentMerchantConfig.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetPaymentMerchantConfig)
async def get_payment_merchant_config_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetPaymentMerchantConfig.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetPaymentTaxConfig)
def get_payment_tax_config(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetPaymentTaxConfig.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetPaymentTaxConfig)
async def get_payment_tax_config_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetPaymentTaxConfig.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetSpecialPaymentProviders)
def get_special_payment_providers(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetSpecialPaymentProviders.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetSpecialPaymentProviders)
async def get_special_payment_providers_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetSpecialPaymentProviders.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryPaymentProviderConfig)
def query_payment_provider_config(
    limit: Optional[int] = None,
    namespace: Optional[str] = None,
    offset: Optional[int] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = QueryPaymentProviderConfig.create(
        limit=limit,
        namespace=namespace,
        offset=offset,
        region=region,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryPaymentProviderConfig)
async def query_payment_provider_config_async(
    limit: Optional[int] = None,
    namespace: Optional[str] = None,
    offset: Optional[int] = None,
    region: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = QueryPaymentProviderConfig.create(
        limit=limit,
        namespace=namespace,
        offset=offset,
        region=region,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestAdyenConfig)
def test_adyen_config(
    body: Optional[AdyenConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAdyenConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestAdyenConfig)
async def test_adyen_config_async(
    body: Optional[AdyenConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAdyenConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestAdyenConfigById)
def test_adyen_config_by_id(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAdyenConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestAdyenConfigById)
async def test_adyen_config_by_id_async(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAdyenConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestAliPayConfig)
def test_ali_pay_config(
    body: Optional[AliPayConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAliPayConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestAliPayConfig)
async def test_ali_pay_config_async(
    body: Optional[AliPayConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAliPayConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestAliPayConfigById)
def test_ali_pay_config_by_id(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAliPayConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestAliPayConfigById)
async def test_ali_pay_config_by_id_async(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestAliPayConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestCheckoutConfig)
def test_checkout_config(
    body: Optional[CheckoutConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestCheckoutConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestCheckoutConfig)
async def test_checkout_config_async(
    body: Optional[CheckoutConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestCheckoutConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestCheckoutConfigById)
def test_checkout_config_by_id(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestCheckoutConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestCheckoutConfigById)
async def test_checkout_config_by_id_async(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestCheckoutConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestPayPalConfig)
def test_pay_pal_config(
    body: Optional[PayPalConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestPayPalConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestPayPalConfig)
async def test_pay_pal_config_async(
    body: Optional[PayPalConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestPayPalConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestPayPalConfigById)
def test_pay_pal_config_by_id(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestPayPalConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestPayPalConfigById)
async def test_pay_pal_config_by_id_async(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestPayPalConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestStripeConfig)
def test_stripe_config(
    body: Optional[StripeConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestStripeConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestStripeConfig)
async def test_stripe_config_async(
    body: Optional[StripeConfig] = None,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestStripeConfig.create(
        body=body,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestStripeConfigById)
def test_stripe_config_by_id(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestStripeConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestStripeConfigById)
async def test_stripe_config_by_id_async(
    id_: str,
    sandbox: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestStripeConfigById.create(
        id_=id_,
        sandbox=sandbox,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestWxPayConfig)
def test_wx_pay_config(
    body: Optional[WxPayConfigRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestWxPayConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestWxPayConfig)
async def test_wx_pay_config_async(
    body: Optional[WxPayConfigRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestWxPayConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestWxPayConfigById)
def test_wx_pay_config_by_id(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = TestWxPayConfigById.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestWxPayConfigById)
async def test_wx_pay_config_by_id_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = TestWxPayConfigById.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestXsollaConfig)
def test_xsolla_config(
    body: Optional[XsollaConfig] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestXsollaConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestXsollaConfig)
async def test_xsolla_config_async(
    body: Optional[XsollaConfig] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestXsollaConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestXsollaConfigById)
def test_xsolla_config_by_id(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = TestXsollaConfigById.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestXsollaConfigById)
async def test_xsolla_config_by_id_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = TestXsollaConfigById.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateAdyenConfig)
def update_adyen_config(
    id_: str,
    body: Optional[AdyenConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateAdyenConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateAdyenConfig)
async def update_adyen_config_async(
    id_: str,
    body: Optional[AdyenConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateAdyenConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateAliPayConfig)
def update_ali_pay_config(
    id_: str,
    body: Optional[AliPayConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateAliPayConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateAliPayConfig)
async def update_ali_pay_config_async(
    id_: str,
    body: Optional[AliPayConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateAliPayConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateCheckoutConfig)
def update_checkout_config(
    id_: str,
    body: Optional[CheckoutConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateCheckoutConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateCheckoutConfig)
async def update_checkout_config_async(
    id_: str,
    body: Optional[CheckoutConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateCheckoutConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdatePayPalConfig)
def update_pay_pal_config(
    id_: str,
    body: Optional[PayPalConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePayPalConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdatePayPalConfig)
async def update_pay_pal_config_async(
    id_: str,
    body: Optional[PayPalConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePayPalConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdatePaymentProviderConfig)
def update_payment_provider_config(
    id_: str,
    body: Optional[PaymentProviderConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePaymentProviderConfig.create(
        id_=id_,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdatePaymentProviderConfig)
async def update_payment_provider_config_async(
    id_: str,
    body: Optional[PaymentProviderConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePaymentProviderConfig.create(
        id_=id_,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdatePaymentTaxConfig)
def update_payment_tax_config(
    body: Optional[PaymentTaxConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePaymentTaxConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdatePaymentTaxConfig)
async def update_payment_tax_config_async(
    body: Optional[PaymentTaxConfigEdit] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdatePaymentTaxConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateStripeConfig)
def update_stripe_config(
    id_: str,
    body: Optional[StripeConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateStripeConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateStripeConfig)
async def update_stripe_config_async(
    id_: str,
    body: Optional[StripeConfig] = None,
    sandbox: Optional[bool] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateStripeConfig.create(
        id_=id_,
        body=body,
        sandbox=sandbox,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateWxPayConfig)
def update_wx_pay_config(
    id_: str,
    body: Optional[WxPayConfigRequest] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateWxPayConfig.create(
        id_=id_,
        body=body,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateWxPayConfig)
async def update_wx_pay_config_async(
    id_: str,
    body: Optional[WxPayConfigRequest] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateWxPayConfig.create(
        id_=id_,
        body=body,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateWxPayConfigCert)
def update_wx_pay_config_cert(
    id_: str,
    file: Optional[Any] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateWxPayConfigCert.create(
        id_=id_,
        file=file,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateWxPayConfigCert)
async def update_wx_pay_config_cert_async(
    id_: str,
    file: Optional[Any] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateWxPayConfigCert.create(
        id_=id_,
        file=file,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateXsollaConfig)
def update_xsolla_config(
    id_: str,
    body: Optional[XsollaConfig] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateXsollaConfig.create(
        id_=id_,
        body=body,
        validate=validate,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateXsollaConfig)
async def update_xsolla_config_async(
    id_: str,
    body: Optional[XsollaConfig] = None,
    validate: Optional[bool] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateXsollaConfig.create(
        id_=id_,
        body=body,
        validate=validate,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateXsollaUIConfig)
def update_xsolla_ui_config(
    id_: str,
    body: Optional[XsollaPaywallConfigRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateXsollaUIConfig.create(
        id_=id_,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateXsollaUIConfig)
async def update_xsolla_ui_config_async(
    id_: str,
    body: Optional[XsollaPaywallConfigRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateXsollaUIConfig.create(
        id_=id_,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Lobby Server (staging)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsPartyData(Model):
    """Models party data (models.PartyData)

    Properties:
        custom_attribute: (custom_attribute) REQUIRED Dict[str, Any]

        invitees: (invitees) REQUIRED List[str]

        leader: (leader) REQUIRED str

        members: (members) REQUIRED List[str]

        namespace: (namespace) REQUIRED str

        party_id: (partyId) REQUIRED str

        updated_at: (updatedAt) REQUIRED int
    """

    # region fields

    custom_attribute: Dict[str, Any]  # REQUIRED
    invitees: List[str]  # REQUIRED
    leader: str  # REQUIRED
    members: List[str]  # REQUIRED
    namespace: str  # REQUIRED
    party_id: str  # REQUIRED
    updated_at: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_custom_attribute(self, value: Dict[str, Any]) -> ModelsPartyData:
        self.custom_attribute = value
        return self

    def with_invitees(self, value: List[str]) -> ModelsPartyData:
        self.invitees = value
        return self

    def with_leader(self, value: str) -> ModelsPartyData:
        self.leader = value
        return self

    def with_members(self, value: List[str]) -> ModelsPartyData:
        self.members = value
        return self

    def with_namespace(self, value: str) -> ModelsPartyData:
        self.namespace = value
        return self

    def with_party_id(self, value: str) -> ModelsPartyData:
        self.party_id = value
        return self

    def with_updated_at(self, value: int) -> ModelsPartyData:
        self.updated_at = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "custom_attribute"):
            result["custom_attribute"] = {
                str(k0): v0 for k0, v0 in self.custom_attribute.items()
            }
        elif include_empty:
            result["custom_attribute"] = {}
        if hasattr(self, "invitees"):
            result["invitees"] = [str(i0) for i0 in self.invitees]
        elif include_empty:
            result["invitees"] = []
        if hasattr(self, "leader"):
            result["leader"] = str(self.leader)
        elif include_empty:
            result["leader"] = ""
        if hasattr(self, "members"):
            result["members"] = [str(i0) for i0 in self.members]
        elif include_empty:
            result["members"] = []
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "party_id"):
            result["partyId"] = str(self.party_id)
        elif include_empty:
            result["partyId"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = int(self.updated_at)
        elif include_empty:
            result["updatedAt"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        custom_attribute: Dict[str, Any],
        invitees: List[str],
        leader: str,
        members: List[str],
        namespace: str,
        party_id: str,
        updated_at: int,
    ) -> ModelsPartyData:
        instance = cls()
        instance.custom_attribute = custom_attribute
        instance.invitees = invitees
        instance.leader = leader
        instance.members = members
        instance.namespace = namespace
        instance.party_id = party_id
        instance.updated_at = updated_at
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsPartyData:
        instance = cls()
        if not dict_:
            return instance
        if "custom_attribute" in dict_ and dict_["custom_attribute"] is not None:
            instance.custom_attribute = {
                str(k0): v0 for k0, v0 in dict_["custom_attribute"].items()
            }
        elif include_empty:
            instance.custom_attribute = {}
        if "invitees" in dict_ and dict_["invitees"] is not None:
            instance.invitees = [str(i0) for i0 in dict_["invitees"]]
        elif include_empty:
            instance.invitees = []
        if "leader" in dict_ and dict_["leader"] is not None:
            instance.leader = str(dict_["leader"])
        elif include_empty:
            instance.leader = ""
        if "members" in dict_ and dict_["members"] is not None:
            instance.members = [str(i0) for i0 in dict_["members"]]
        elif include_empty:
            instance.members = []
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "partyId" in dict_ and dict_["partyId"] is not None:
            instance.party_id = str(dict_["partyId"])
        elif include_empty:
            instance.party_id = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = int(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsPartyData]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsPartyData]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ModelsPartyData, List[ModelsPartyData], Dict[Any, ModelsPartyData]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "custom_attribute": "custom_attribute",
            "invitees": "invitees",
            "leader": "leader",
            "members": "members",
            "namespace": "namespace",
            "partyId": "party_id",
            "updatedAt": "updated_at",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "custom_attribute": True,
            "invitees": True,
            "leader": True,
            "members": True,
            "namespace": True,
            "partyId": True,
            "updatedAt": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsCreateConfigRequest
from ..models import ModelsCreateConfigResponse
from ..models import ModelsGetConfigResponse
from ..models import ModelsUpdateConfigRequest
from ..models import ModelsUpdateConfigResponse
from ..models import RestapiErrorResponseV1

from ..operations.third_party import AdminCreateThirdPartyConfig
from ..operations.third_party import AdminDeleteThirdPartyConfig
from ..operations.third_party import AdminGetThirdPartyConfig
from ..operations.third_party import AdminUpdateThirdPartyConfig


@same_doc_as(AdminCreateThirdPartyConfig)
def admin_create_third_party_config(
    body: ModelsCreateConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateThirdPartyConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCreateThirdPartyConfig)
async def admin_create_third_party_config_async(
    body: ModelsCreateConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCreateThirdPartyConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteThirdPartyConfig)
def admin_delete_third_party_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteThirdPartyConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteThirdPartyConfig)
async def admin_delete_third_party_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteThirdPartyConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetThirdPartyConfig)
def admin_get_third_party_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetThirdPartyConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetThirdPartyConfig)
async def admin_get_third_party_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetThirdPartyConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateThirdPartyConfig)
def admin_update_third_party_config(
    body: ModelsUpdateConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateThirdPartyConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateThirdPartyConfig)
async def admin_update_third_party_config_async(
    body: ModelsUpdateConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateThirdPartyConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.17.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class InGameItemSync(Model):
    """In game item sync (InGameItemSync)

    Properties:
        category_path: (categoryPath) REQUIRED str

        target_item_id: (targetItemId) REQUIRED str

        target_namespace: (targetNamespace) REQUIRED str
    """

    # region fields

    category_path: str  # REQUIRED
    target_item_id: str  # REQUIRED
    target_namespace: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_category_path(self, value: str) -> InGameItemSync:
        self.category_path = value
        return self

    def with_target_item_id(self, value: str) -> InGameItemSync:
        self.target_item_id = value
        return self

    def with_target_namespace(self, value: str) -> InGameItemSync:
        self.target_namespace = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "category_path"):
            result["categoryPath"] = str(self.category_path)
        elif include_empty:
            result["categoryPath"] = ""
        if hasattr(self, "target_item_id"):
            result["targetItemId"] = str(self.target_item_id)
        elif include_empty:
            result["targetItemId"] = ""
        if hasattr(self, "target_namespace"):
            result["targetNamespace"] = str(self.target_namespace)
        elif include_empty:
            result["targetNamespace"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        category_path: str,
        target_item_id: str,
        target_namespace: str,
    ) -> InGameItemSync:
        instance = cls()
        instance.category_path = category_path
        instance.target_item_id = target_item_id
        instance.target_namespace = target_namespace
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> InGameItemSync:
        instance = cls()
        if not dict_:
            return instance
        if "categoryPath" in dict_ and dict_["categoryPath"] is not None:
            instance.category_path = str(dict_["categoryPath"])
        elif include_empty:
            instance.category_path = ""
        if "targetItemId" in dict_ and dict_["targetItemId"] is not None:
            instance.target_item_id = str(dict_["targetItemId"])
        elif include_empty:
            instance.target_item_id = ""
        if "targetNamespace" in dict_ and dict_["targetNamespace"] is not None:
            instance.target_namespace = str(dict_["targetNamespace"])
        elif include_empty:
            instance.target_namespace = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, InGameItemSync]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[InGameItemSync]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[InGameItemSync, List[InGameItemSync], Dict[Any, InGameItemSync]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "categoryPath": "category_path",
            "targetItemId": "target_item_id",
            "targetNamespace": "target_namespace",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "categoryPath": True,
            "targetItemId": True,
            "targetNamespace": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Achievement Service ()

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsAdditionalInfo(Model):
    """Models additional info (models.AdditionalInfo)

    Properties:
        number_of_achievements: (numberOfAchievements) REQUIRED int

        number_of_hidden_achievements: (numberOfHiddenAchievements) REQUIRED int

        number_of_visible_achievements: (numberOfVisibleAchievements) REQUIRED int
    """

    # region fields

    number_of_achievements: int  # REQUIRED
    number_of_hidden_achievements: int  # REQUIRED
    number_of_visible_achievements: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_number_of_achievements(self, value: int) -> ModelsAdditionalInfo:
        self.number_of_achievements = value
        return self

    def with_number_of_hidden_achievements(self, value: int) -> ModelsAdditionalInfo:
        self.number_of_hidden_achievements = value
        return self

    def with_number_of_visible_achievements(self, value: int) -> ModelsAdditionalInfo:
        self.number_of_visible_achievements = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "number_of_achievements"):
            result["numberOfAchievements"] = int(self.number_of_achievements)
        elif include_empty:
            result["numberOfAchievements"] = 0
        if hasattr(self, "number_of_hidden_achievements"):
            result["numberOfHiddenAchievements"] = int(
                self.number_of_hidden_achievements
            )
        elif include_empty:
            result["numberOfHiddenAchievements"] = 0
        if hasattr(self, "number_of_visible_achievements"):
            result["numberOfVisibleAchievements"] = int(
                self.number_of_visible_achievements
            )
        elif include_empty:
            result["numberOfVisibleAchievements"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        number_of_achievements: int,
        number_of_hidden_achievements: int,
        number_of_visible_achievements: int,
    ) -> ModelsAdditionalInfo:
        instance = cls()
        instance.number_of_achievements = number_of_achievements
        instance.number_of_hidden_achievements = number_of_hidden_achievements
        instance.number_of_visible_achievements = number_of_visible_achievements
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsAdditionalInfo:
        instance = cls()
        if not dict_:
            return instance
        if (
            "numberOfAchievements" in dict_
            and dict_["numberOfAchievements"] is not None
        ):
            instance.number_of_achievements = int(dict_["numberOfAchievements"])
        elif include_empty:
            instance.number_of_achievements = 0
        if (
            "numberOfHiddenAchievements" in dict_
            and dict_["numberOfHiddenAchievements"] is not None
        ):
            instance.number_of_hidden_achievements = int(
                dict_["numberOfHiddenAchievements"]
            )
        elif include_empty:
            instance.number_of_hidden_achievements = 0
        if (
            "numberOfVisibleAchievements" in dict_
            and dict_["numberOfVisibleAchievements"] is not None
        ):
            instance.number_of_visible_achievements = int(
                dict_["numberOfVisibleAchievements"]
            )
        elif include_empty:
            instance.number_of_visible_achievements = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsAdditionalInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsAdditionalInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsAdditionalInfo,
        List[ModelsAdditionalInfo],
        Dict[Any, ModelsAdditionalInfo],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "numberOfAchievements": "number_of_achievements",
            "numberOfHiddenAchievements": "number_of_hidden_achievements",
            "numberOfVisibleAchievements": "number_of_visible_achievements",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "numberOfAchievements": True,
            "numberOfHiddenAchievements": True,
            "numberOfVisibleAchievements": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Group Service."""

__version__ = "2.11.9"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .accept_group_invitation_27bb3d import AcceptGroupInvitationPublicV1
from .accept_group_join_reque_5995a4 import AcceptGroupJoinRequestPublicV1
from .cancel_group_join_request_v1 import CancelGroupJoinRequestV1
from .get_group_members_list__2e05f5 import GetGroupMembersListAdminV1
from .get_group_members_list__b75ca5 import GetGroupMembersListPublicV1
from .get_user_group_informat_51aafe import GetUserGroupInformationPublicV1
from .invite_group_public_v1 import InviteGroupPublicV1
from .join_group_v1 import JoinGroupV1
from .kick_group_member_public_v1 import KickGroupMemberPublicV1
from .leave_group_public_v1 import LeaveGroupPublicV1
from .reject_group_invitation_c6a225 import RejectGroupInvitationPublicV1
from .reject_group_join_reque_85b3af import RejectGroupJoinRequestPublicV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.17.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
import re
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class TypeEnum(StrEnum):
    APPLE = "APPLE"
    EPICGAMES = "EPICGAMES"
    GOOGLE = "GOOGLE"
    PLAYSTATION = "PLAYSTATION"
    STADIA = "STADIA"
    STEAM = "STEAM"
    TWITCH = "TWITCH"
    XBOX = "XBOX"


class ItemIdentityTypeEnum(StrEnum):
    ITEM_ID = "ITEM_ID"
    ITEM_SKU = "ITEM_SKU"


class MockIAPReceipt(Model):
    """Mock IAP receipt (MockIAPReceipt)

    Properties:
        product_id: (productId) REQUIRED str

        type_: (type) REQUIRED Union[str, TypeEnum]

        item_identity_type: (itemIdentityType) OPTIONAL Union[str, ItemIdentityTypeEnum]

        language: (language) OPTIONAL str

        region: (region) OPTIONAL str
    """

    # region fields

    product_id: str  # REQUIRED
    type_: Union[str, TypeEnum]  # REQUIRED
    item_identity_type: Union[str, ItemIdentityTypeEnum]  # OPTIONAL
    language: str  # OPTIONAL
    region: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_product_id(self, value: str) -> MockIAPReceipt:
        self.product_id = value
        return self

    def with_type(self, value: Union[str, TypeEnum]) -> MockIAPReceipt:
        self.type_ = value
        return self

    def with_item_identity_type(
        self, value: Union[str, ItemIdentityTypeEnum]
    ) -> MockIAPReceipt:
        self.item_identity_type = value
        return self

    def with_language(self, value: str) -> MockIAPReceipt:
        self.language = value
        return self

    def with_region(self, value: str) -> MockIAPReceipt:
        self.region = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "product_id"):
            result["productId"] = str(self.product_id)
        elif include_empty:
            result["productId"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = Union[str, TypeEnum]()
        if hasattr(self, "item_identity_type"):
            result["itemIdentityType"] = str(self.item_identity_type)
        elif include_empty:
            result["itemIdentityType"] = Union[str, ItemIdentityTypeEnum]()
        if hasattr(self, "language"):
            result["language"] = str(self.language)
        elif include_empty:
            result["language"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        product_id: str,
        type_: Union[str, TypeEnum],
        item_identity_type: Optional[Union[str, ItemIdentityTypeEnum]] = None,
        language: Optional[str] = None,
        region: Optional[str] = None,
    ) -> MockIAPReceipt:
        instance = cls()
        instance.product_id = product_id
        instance.type_ = type_
        if item_identity_type is not None:
            instance.item_identity_type = item_identity_type
        if language is not None:
            instance.language = language
        if region is not None:
            instance.region = region
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> MockIAPReceipt:
        instance = cls()
        if not dict_:
            return instance
        if "productId" in dict_ and dict_["productId"] is not None:
            instance.product_id = str(dict_["productId"])
        elif include_empty:
            instance.product_id = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = Union[str, TypeEnum]()
        if "itemIdentityType" in dict_ and dict_["itemIdentityType"] is not None:
            instance.item_identity_type = str(dict_["itemIdentityType"])
        elif include_empty:
            instance.item_identity_type = Union[str, ItemIdentityTypeEnum]()
        if "language" in dict_ and dict_["language"] is not None:
            instance.language = str(dict_["language"])
        elif include_empty:
            instance.language = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, MockIAPReceipt]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[MockIAPReceipt]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[MockIAPReceipt, List[MockIAPReceipt], Dict[Any, MockIAPReceipt]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "productId": "product_id",
            "type": "type_",
            "itemIdentityType": "item_identity_type",
            "language": "language",
            "region": "region",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "productId": True,
            "type": True,
            "itemIdentityType": False,
            "language": False,
            "region": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "type": [
                "APPLE",
                "EPICGAMES",
                "GOOGLE",
                "PLAYSTATION",
                "STADIA",
                "STEAM",
                "TWITCH",
                "XBOX",
            ],
            "itemIdentityType": ["ITEM_ID", "ITEM_SKU"],
        }

    @staticmethod
    def get_pattern_map() -> Dict[str, re.Pattern]:
        return {
            "language": re.compile(
                r"^[A-Za-z]{2,4}([_-][A-Za-z]{4})?([_-]([A-Za-z]{2}|[0-9]{3}))?$"
            ),
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_user_permission import AddUserPermission
from .add_user_role import AddUserRole
from .admin_add_user_permissions_v3 import AdminAddUserPermissionsV3
from .admin_add_user_role_v3 import AdminAddUserRoleV3
from .admin_ban_user_v2 import AdminBanUserV2
from .admin_ban_user_v3 import AdminBanUserV3
from .admin_create_justice_user import AdminCreateJusticeUser
from .admin_create_user_roles_v2 import AdminCreateUserRolesV2
from .admin_delete_platform_link_v2 import AdminDeletePlatformLinkV2
from .admin_delete_user_infor_aae072 import AdminDeleteUserInformationV3
from .admin_delete_user_permi_6b5aa5 import AdminDeleteUserPermissionBulkV3
from .admin_delete_user_permi_b5683d import AdminDeleteUserPermissionV3
from .admin_delete_user_role_v3 import AdminDeleteUserRoleV3
from .admin_delete_user_roles_v3 import AdminDeleteUserRolesV3
from .admin_disable_user_v2 import AdminDisableUserV2
from .admin_enable_user_v2 import AdminEnableUserV2
from .admin_get_age_restricti_48366c import AdminGetAgeRestrictionStatusV2
from .admin_get_age_restricti_5a6b02 import AdminGetAgeRestrictionStatusV3
from .admin_get_bulk_user_by__b42a39 import AdminGetBulkUserByEmailAddressV3
from .admin_get_list_country__a160f3 import AdminGetListCountryAgeRestrictionV3
from .admin_get_list_justice__0399f2 import AdminGetListJusticePlatformAccounts
from .admin_get_my_user_v3 import AdminGetMyUserV3
from .admin_get_user_ban_v2 import AdminGetUserBanV2
from .admin_get_user_ban_v3 import AdminGetUserBanV3
from .admin_get_user_by_email_160113 import AdminGetUserByEmailAddressV3
from .admin_get_user_by_platf_63b0f0 import AdminGetUserByPlatformUserIDV3
from .admin_get_user_by_user_id_v2 import AdminGetUserByUserIdV2
from .admin_get_user_by_user_id_v3 import AdminGetUserByUserIdV3
from .admin_get_user_deletion_d1510f import AdminGetUserDeletionStatusV3
from .admin_get_user_login_hi_f4b37e import AdminGetUserLoginHistoriesV3
from .admin_get_user_mapping import AdminGetUserMapping
from .admin_get_user_platform_6f9923 import AdminGetUserPlatformAccountsV3
from .admin_invite_user_v3 import AdminInviteUserV3
from .admin_link_platform_account import AdminLinkPlatformAccount
from .admin_list_user_id_by_u_d47f71 import AdminListUserIDByUserIDsV3
from .admin_list_users_v3 import AdminListUsersV3
from .admin_platform_link_v3 import AdminPlatformLinkV3
from .admin_platform_unlink_v3 import AdminPlatformUnlinkV3
from .admin_put_user_roles_v2 import AdminPutUserRolesV2
from .admin_reset_password_v2 import AdminResetPasswordV2
from .admin_reset_password_v3 import AdminResetPasswordV3
from .admin_save_user_role_v3 import AdminSaveUserRoleV3
from .admin_search_user_v3 import AdminSearchUserV3
from .admin_search_users_v2 import AdminSearchUsersV2
from .admin_send_verification_c07f19 import AdminSendVerificationCodeV3
from .admin_update_age_restri_71a4c3 import AdminUpdateAgeRestrictionConfigV2
from .admin_update_age_restri_63e13a import AdminUpdateAgeRestrictionConfigV3
from .admin_update_country_ag_e486e0 import AdminUpdateCountryAgeRestrictionV3
from .admin_update_user_ban_v3 import AdminUpdateUserBanV3
from .admin_update_user_delet_586395 import AdminUpdateUserDeletionStatusV3
from .admin_update_user_permi_7a3e2f import AdminUpdateUserPermissionV3
from .admin_update_user_status_v3 import AdminUpdateUserStatusV3
from .admin_update_user_v2 import AdminUpdateUserV2
from .admin_update_user_v3 import AdminUpdateUserV3
from .admin_upgrade_headless__8c85b9 import AdminUpgradeHeadlessAccountV3
from .admin_verify_account_v3 import AdminVerifyAccountV3
from .admin_verify_user_witho_8cd19e import AdminVerifyUserWithoutVerificationCodeV3
from .ban_user import BanUser
from .check_user_availability import CheckUserAvailability
from .create_user import CreateUser
from .create_user_from_invitation_v3 import CreateUserFromInvitationV3
from .delete_user import DeleteUser
from .delete_user_information import DeleteUserInformation
from .delete_user_permission import DeleteUserPermission
from .delete_user_role import DeleteUserRole
from .disable_user import DisableUser
from .disable_user_ban import DisableUserBan
from .enable_user import EnableUser
from .enable_user_ban import EnableUserBan
from .forgot_password import ForgotPassword
from .get_admin_invitation_v3 import GetAdminInvitationV3
from .get_admin_users_by_role_id import GetAdminUsersByRoleID
from .get_admin_users_by_role_id_v3 import GetAdminUsersByRoleIdV3
from .get_list_country_age_re_475567 import GetListCountryAgeRestriction
from .get_list_justice_platfo_993905 import GetListJusticePlatformAccounts
from .get_publisher_user import GetPublisherUser
from .get_user_ban_history import GetUserBanHistory
from .get_user_by_login_id import GetUserByLoginID
from .get_user_by_platform_user_id import GetUserByPlatformUserID
from .get_user_by_user_id import GetUserByUserID
from .get_user_information import GetUserInformation
from .get_user_justice_platfo_879dca import GetUserJusticePlatformAccount
from .get_user_login_histories import GetUserLoginHistories
from .get_user_mapping import GetUserMapping
from .get_user_platform_accounts import GetUserPlatformAccounts
from .get_user_verification_code import GetUserVerificationCode
from .get_users_by_login_ids import GetUsersByLoginIds
from .list_admins_v3 import ListAdminsV3
from .list_cross_namespace_ac_234b9e import ListCrossNamespaceAccountLink
from .platform_link import PlatformLink
from .platform_unlink import PlatformUnlink
from .public_bulk_get_users import PublicBulkGetUsers
from .public_create_justice_user import PublicCreateJusticeUser
from .public_create_user_v2 import PublicCreateUserV2
from .public_create_user_v3 import PublicCreateUserV3
from .public_delete_platform_link_v2 import PublicDeletePlatformLinkV2
from .public_force_link_platf_1f3822 import PublicForceLinkPlatformWithProgression
from .public_force_platform_link_v3 import PublicForcePlatformLinkV3
from .public_forgot_password_v2 import PublicForgotPasswordV2
from .public_forgot_password_v3 import PublicForgotPasswordV3
from .public_get_async_status import PublicGetAsyncStatus
from .public_get_country_age__7cfd03 import PublicGetCountryAgeRestriction
from .public_get_country_age__e3af67 import PublicGetCountryAgeRestrictionV3
from .public_get_my_user_v3 import PublicGetMyUserV3
from .public_get_publisher_user_v3 import PublicGetPublisherUserV3
from .public_get_user_ban import PublicGetUserBan
from .public_get_user_ban_history_v3 import PublicGetUserBanHistoryV3
from .public_get_user_by_plat_ae1e0a import PublicGetUserByPlatformUserIDV3
from .public_get_user_by_user_id_v3 import PublicGetUserByUserIdV3
from .public_get_user_by_user_idv2 import PublicGetUserByUserIDV2
from .public_get_user_information_v3 import PublicGetUserInformationV3
from .public_get_user_login_h_60bd12 import PublicGetUserLoginHistoriesV3
from .public_get_user_platfor_890bc0 import PublicGetUserPlatformAccountsV3
from .public_link_platform_account import PublicLinkPlatformAccount
from .public_list_justice_pla_bd1791 import PublicListJusticePlatformAccountsV3
from .public_list_user_all_pl_0f3031 import PublicListUserAllPlatformAccountsDistinctV3
from .public_list_user_id_by__d6f348 import PublicListUserIDByPlatformUserIDsV3
from .public_partial_update_user_v3 import PublicPartialUpdateUserV3
from .public_platform_link_v2 import PublicPlatformLinkV2
from .public_platform_link_v3 import PublicPlatformLinkV3
from .public_platform_unlink_all_v3 import PublicPlatformUnlinkAllV3
from .public_platform_unlink_v3 import PublicPlatformUnlinkV3
from .public_reset_password_v2 import PublicResetPasswordV2
from .public_search_user_v3 import PublicSearchUserV3
from .public_send_registration_code import PublicSendRegistrationCode
from .public_send_verificatio_dc732c import PublicSendVerificationCodeV3
from .public_send_verificatio_1a545f import PublicSendVerificationLinkV3
from .public_update_password_v2 import PublicUpdatePasswordV2
from .public_update_password_v3 import PublicUpdatePasswordV3
from .public_update_user_v2 import PublicUpdateUserV2
from .public_upgrade_headless_a93947 import PublicUpgradeHeadlessAccountV3
from .public_user_verification_v3 import PublicUserVerificationV3
from .public_validate_user_by_fc4982 import PublicValidateUserByUserIDAndPasswordV3
from .public_verify_headless__2e6c24 import PublicVerifyHeadlessAccountV3
from .public_verify_registrat_4d06db import PublicVerifyRegistrationCode
from .public_verify_user_by_link_v3 import PublicVerifyUserByLinkV3
from .public_web_link_platform import PublicWebLinkPlatform
from .public_web_link_platfor_667cbd import PublicWebLinkPlatformEstablish
from .reset_password import ResetPassword
from .reset_password_v3 import ResetPasswordV3
from .save_user_permission import SaveUserPermission
from .save_user_roles import SaveUserRoles
from .search_user import SearchUser
from .send_verification_code import SendVerificationCode
from .update_country_age_restriction import UpdateCountryAgeRestriction
from .update_password import UpdatePassword
from .update_user import UpdateUser
from .update_user_v3 import UpdateUserV3
from .upgrade_headless_account import UpgradeHeadlessAccount
from .upgrade_headless_accoun_cd2d1f import UpgradeHeadlessAccountWithVerificationCode
from .user_verification import UserVerification



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Dsm Controller Service (3.10.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_allocation_event import ModelsAllocationEvent
from ..models.models_status_history import ModelsStatusHistory


class ModelsServer(Model):
    """Models server (models.Server)

    Properties:
        allocation_events: (allocation_events) REQUIRED List[ModelsAllocationEvent]

        allocation_id: (allocation_id) REQUIRED str

        alternate_ips: (alternate_ips) REQUIRED List[str]

        cpu_limit: (cpu_limit) REQUIRED int

        created_at: (created_at) REQUIRED str

        custom_attribute: (custom_attribute) REQUIRED str

        deployment: (deployment) REQUIRED str

        game_version: (game_version) REQUIRED str

        image_version: (image_version) REQUIRED str

        ip: (ip) REQUIRED str

        is_override_game_version: (is_override_game_version) REQUIRED bool

        job_id: (job_id) REQUIRED str

        last_update: (last_update) REQUIRED str

        mem_limit: (mem_limit) REQUIRED int

        namespace: (namespace) REQUIRED str

        params: (params) REQUIRED str

        pod_name: (pod_name) REQUIRED str

        port: (port) REQUIRED int

        ports: (ports) REQUIRED Dict[str, int]

        protocol: (protocol) REQUIRED str

        provider: (provider) REQUIRED str

        region: (region) REQUIRED str

        session_id: (session_id) REQUIRED str

        status: (status) REQUIRED str

        status_history: (status_history) REQUIRED List[ModelsStatusHistory]
    """

    # region fields

    allocation_events: List[ModelsAllocationEvent]  # REQUIRED
    allocation_id: str  # REQUIRED
    alternate_ips: List[str]  # REQUIRED
    cpu_limit: int  # REQUIRED
    created_at: str  # REQUIRED
    custom_attribute: str  # REQUIRED
    deployment: str  # REQUIRED
    game_version: str  # REQUIRED
    image_version: str  # REQUIRED
    ip: str  # REQUIRED
    is_override_game_version: bool  # REQUIRED
    job_id: str  # REQUIRED
    last_update: str  # REQUIRED
    mem_limit: int  # REQUIRED
    namespace: str  # REQUIRED
    params: str  # REQUIRED
    pod_name: str  # REQUIRED
    port: int  # REQUIRED
    ports: Dict[str, int]  # REQUIRED
    protocol: str  # REQUIRED
    provider: str  # REQUIRED
    region: str  # REQUIRED
    session_id: str  # REQUIRED
    status: str  # REQUIRED
    status_history: List[ModelsStatusHistory]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_allocation_events(
        self, value: List[ModelsAllocationEvent]
    ) -> ModelsServer:
        self.allocation_events = value
        return self

    def with_allocation_id(self, value: str) -> ModelsServer:
        self.allocation_id = value
        return self

    def with_alternate_ips(self, value: List[str]) -> ModelsServer:
        self.alternate_ips = value
        return self

    def with_cpu_limit(self, value: int) -> ModelsServer:
        self.cpu_limit = value
        return self

    def with_created_at(self, value: str) -> ModelsServer:
        self.created_at = value
        return self

    def with_custom_attribute(self, value: str) -> ModelsServer:
        self.custom_attribute = value
        return self

    def with_deployment(self, value: str) -> ModelsServer:
        self.deployment = value
        return self

    def with_game_version(self, value: str) -> ModelsServer:
        self.game_version = value
        return self

    def with_image_version(self, value: str) -> ModelsServer:
        self.image_version = value
        return self

    def with_ip(self, value: str) -> ModelsServer:
        self.ip = value
        return self

    def with_is_override_game_version(self, value: bool) -> ModelsServer:
        self.is_override_game_version = value
        return self

    def with_job_id(self, value: str) -> ModelsServer:
        self.job_id = value
        return self

    def with_last_update(self, value: str) -> ModelsServer:
        self.last_update = value
        return self

    def with_mem_limit(self, value: int) -> ModelsServer:
        self.mem_limit = value
        return self

    def with_namespace(self, value: str) -> ModelsServer:
        self.namespace = value
        return self

    def with_params(self, value: str) -> ModelsServer:
        self.params = value
        return self

    def with_pod_name(self, value: str) -> ModelsServer:
        self.pod_name = value
        return self

    def with_port(self, value: int) -> ModelsServer:
        self.port = value
        return self

    def with_ports(self, value: Dict[str, int]) -> ModelsServer:
        self.ports = value
        return self

    def with_protocol(self, value: str) -> ModelsServer:
        self.protocol = value
        return self

    def with_provider(self, value: str) -> ModelsServer:
        self.provider = value
        return self

    def with_region(self, value: str) -> ModelsServer:
        self.region = value
        return self

    def with_session_id(self, value: str) -> ModelsServer:
        self.session_id = value
        return self

    def with_status(self, value: str) -> ModelsServer:
        self.status = value
        return self

    def with_status_history(self, value: List[ModelsStatusHistory]) -> ModelsServer:
        self.status_history = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "allocation_events"):
            result["allocation_events"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.allocation_events
            ]
        elif include_empty:
            result["allocation_events"] = []
        if hasattr(self, "allocation_id"):
            result["allocation_id"] = str(self.allocation_id)
        elif include_empty:
            result["allocation_id"] = ""
        if hasattr(self, "alternate_ips"):
            result["alternate_ips"] = [str(i0) for i0 in self.alternate_ips]
        elif include_empty:
            result["alternate_ips"] = []
        if hasattr(self, "cpu_limit"):
            result["cpu_limit"] = int(self.cpu_limit)
        elif include_empty:
            result["cpu_limit"] = 0
        if hasattr(self, "created_at"):
            result["created_at"] = str(self.created_at)
        elif include_empty:
            result["created_at"] = ""
        if hasattr(self, "custom_attribute"):
            result["custom_attribute"] = str(self.custom_attribute)
        elif include_empty:
            result["custom_attribute"] = ""
        if hasattr(self, "deployment"):
            result["deployment"] = str(self.deployment)
        elif include_empty:
            result["deployment"] = ""
        if hasattr(self, "game_version"):
            result["game_version"] = str(self.game_version)
        elif include_empty:
            result["game_version"] = ""
        if hasattr(self, "image_version"):
            result["image_version"] = str(self.image_version)
        elif include_empty:
            result["image_version"] = ""
        if hasattr(self, "ip"):
            result["ip"] = str(self.ip)
        elif include_empty:
            result["ip"] = ""
        if hasattr(self, "is_override_game_version"):
            result["is_override_game_version"] = bool(self.is_override_game_version)
        elif include_empty:
            result["is_override_game_version"] = False
        if hasattr(self, "job_id"):
            result["job_id"] = str(self.job_id)
        elif include_empty:
            result["job_id"] = ""
        if hasattr(self, "last_update"):
            result["last_update"] = str(self.last_update)
        elif include_empty:
            result["last_update"] = ""
        if hasattr(self, "mem_limit"):
            result["mem_limit"] = int(self.mem_limit)
        elif include_empty:
            result["mem_limit"] = 0
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "params"):
            result["params"] = str(self.params)
        elif include_empty:
            result["params"] = ""
        if hasattr(self, "pod_name"):
            result["pod_name"] = str(self.pod_name)
        elif include_empty:
            result["pod_name"] = ""
        if hasattr(self, "port"):
            result["port"] = int(self.port)
        elif include_empty:
            result["port"] = 0
        if hasattr(self, "ports"):
            result["ports"] = {str(k0): int(v0) for k0, v0 in self.ports.items()}
        elif include_empty:
            result["ports"] = {}
        if hasattr(self, "protocol"):
            result["protocol"] = str(self.protocol)
        elif include_empty:
            result["protocol"] = ""
        if hasattr(self, "provider"):
            result["provider"] = str(self.provider)
        elif include_empty:
            result["provider"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "session_id"):
            result["session_id"] = str(self.session_id)
        elif include_empty:
            result["session_id"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "status_history"):
            result["status_history"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.status_history
            ]
        elif include_empty:
            result["status_history"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        allocation_events: List[ModelsAllocationEvent],
        allocation_id: str,
        alternate_ips: List[str],
        cpu_limit: int,
        created_at: str,
        custom_attribute: str,
        deployment: str,
        game_version: str,
        image_version: str,
        ip: str,
        is_override_game_version: bool,
        job_id: str,
        last_update: str,
        mem_limit: int,
        namespace: str,
        params: str,
        pod_name: str,
        port: int,
        ports: Dict[str, int],
        protocol: str,
        provider: str,
        region: str,
        session_id: str,
        status: str,
        status_history: List[ModelsStatusHistory],
    ) -> ModelsServer:
        instance = cls()
        instance.allocation_events = allocation_events
        instance.allocation_id = allocation_id
        instance.alternate_ips = alternate_ips
        instance.cpu_limit = cpu_limit
        instance.created_at = created_at
        instance.custom_attribute = custom_attribute
        instance.deployment = deployment
        instance.game_version = game_version
        instance.image_version = image_version
        instance.ip = ip
        instance.is_override_game_version = is_override_game_version
        instance.job_id = job_id
        instance.last_update = last_update
        instance.mem_limit = mem_limit
        instance.namespace = namespace
        instance.params = params
        instance.pod_name = pod_name
        instance.port = port
        instance.ports = ports
        instance.protocol = protocol
        instance.provider = provider
        instance.region = region
        instance.session_id = session_id
        instance.status = status
        instance.status_history = status_history
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ModelsServer:
        instance = cls()
        if not dict_:
            return instance
        if "allocation_events" in dict_ and dict_["allocation_events"] is not None:
            instance.allocation_events = [
                ModelsAllocationEvent.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["allocation_events"]
            ]
        elif include_empty:
            instance.allocation_events = []
        if "allocation_id" in dict_ and dict_["allocation_id"] is not None:
            instance.allocation_id = str(dict_["allocation_id"])
        elif include_empty:
            instance.allocation_id = ""
        if "alternate_ips" in dict_ and dict_["alternate_ips"] is not None:
            instance.alternate_ips = [str(i0) for i0 in dict_["alternate_ips"]]
        elif include_empty:
            instance.alternate_ips = []
        if "cpu_limit" in dict_ and dict_["cpu_limit"] is not None:
            instance.cpu_limit = int(dict_["cpu_limit"])
        elif include_empty:
            instance.cpu_limit = 0
        if "created_at" in dict_ and dict_["created_at"] is not None:
            instance.created_at = str(dict_["created_at"])
        elif include_empty:
            instance.created_at = ""
        if "custom_attribute" in dict_ and dict_["custom_attribute"] is not None:
            instance.custom_attribute = str(dict_["custom_attribute"])
        elif include_empty:
            instance.custom_attribute = ""
        if "deployment" in dict_ and dict_["deployment"] is not None:
            instance.deployment = str(dict_["deployment"])
        elif include_empty:
            instance.deployment = ""
        if "game_version" in dict_ and dict_["game_version"] is not None:
            instance.game_version = str(dict_["game_version"])
        elif include_empty:
            instance.game_version = ""
        if "image_version" in dict_ and dict_["image_version"] is not None:
            instance.image_version = str(dict_["image_version"])
        elif include_empty:
            instance.image_version = ""
        if "ip" in dict_ and dict_["ip"] is not None:
            instance.ip = str(dict_["ip"])
        elif include_empty:
            instance.ip = ""
        if (
            "is_override_game_version" in dict_
            and dict_["is_override_game_version"] is not None
        ):
            instance.is_override_game_version = bool(dict_["is_override_game_version"])
        elif include_empty:
            instance.is_override_game_version = False
        if "job_id" in dict_ and dict_["job_id"] is not None:
            instance.job_id = str(dict_["job_id"])
        elif include_empty:
            instance.job_id = ""
        if "last_update" in dict_ and dict_["last_update"] is not None:
            instance.last_update = str(dict_["last_update"])
        elif include_empty:
            instance.last_update = ""
        if "mem_limit" in dict_ and dict_["mem_limit"] is not None:
            instance.mem_limit = int(dict_["mem_limit"])
        elif include_empty:
            instance.mem_limit = 0
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "params" in dict_ and dict_["params"] is not None:
            instance.params = str(dict_["params"])
        elif include_empty:
            instance.params = ""
        if "pod_name" in dict_ and dict_["pod_name"] is not None:
            instance.pod_name = str(dict_["pod_name"])
        elif include_empty:
            instance.pod_name = ""
        if "port" in dict_ and dict_["port"] is not None:
            instance.port = int(dict_["port"])
        elif include_empty:
            instance.port = 0
        if "ports" in dict_ and dict_["ports"] is not None:
            instance.ports = {str(k0): int(v0) for k0, v0 in dict_["ports"].items()}
        elif include_empty:
            instance.ports = {}
        if "protocol" in dict_ and dict_["protocol"] is not None:
            instance.protocol = str(dict_["protocol"])
        elif include_empty:
            instance.protocol = ""
        if "provider" in dict_ and dict_["provider"] is not None:
            instance.provider = str(dict_["provider"])
        elif include_empty:
            instance.provider = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "session_id" in dict_ and dict_["session_id"] is not None:
            instance.session_id = str(dict_["session_id"])
        elif include_empty:
            instance.session_id = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "status_history" in dict_ and dict_["status_history"] is not None:
            instance.status_history = [
                ModelsStatusHistory.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["status_history"]
            ]
        elif include_empty:
            instance.status_history = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsServer]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsServer]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ModelsServer, List[ModelsServer], Dict[Any, ModelsServer]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "allocation_events": "allocation_events",
            "allocation_id": "allocation_id",
            "alternate_ips": "alternate_ips",
            "cpu_limit": "cpu_limit",
            "created_at": "created_at",
            "custom_attribute": "custom_attribute",
            "deployment": "deployment",
            "game_version": "game_version",
            "image_version": "image_version",
            "ip": "ip",
            "is_override_game_version": "is_override_game_version",
            "job_id": "job_id",
            "last_update": "last_update",
            "mem_limit": "mem_limit",
            "namespace": "namespace",
            "params": "params",
            "pod_name": "pod_name",
            "port": "port",
            "ports": "ports",
            "protocol": "protocol",
            "provider": "provider",
            "region": "region",
            "session_id": "session_id",
            "status": "status",
            "status_history": "status_history",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "allocation_events": True,
            "allocation_id": True,
            "alternate_ips": True,
            "cpu_limit": True,
            "created_at": True,
            "custom_attribute": True,
            "deployment": True,
            "game_version": True,
            "image_version": True,
            "ip": True,
            "is_override_game_version": True,
            "job_id": True,
            "last_update": True,
            "mem_limit": True,
            "namespace": True,
            "params": True,
            "pod_name": True,
            "port": True,
            "ports": True,
            "protocol": True,
            "provider": True,
            "region": True,
            "session_id": True,
            "status": True,
            "status_history": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.20.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class AccountcommonUserLinkedPlatformV3(Model):
    """Accountcommon user linked platform V3 (accountcommon.UserLinkedPlatformV3)

    Properties:
        account_group: (accountGroup) REQUIRED str

        linked_at: (linkedAt) REQUIRED str

        namespace: (namespace) REQUIRED str

        origin_namespace: (originNamespace) REQUIRED str

        user_id: (userId) REQUIRED str

        display_name: (displayName) OPTIONAL str

        email_address: (emailAddress) OPTIONAL str

        platform_id: (platformId) OPTIONAL str

        platform_user_id: (platformUserId) OPTIONAL str
    """

    # region fields

    account_group: str  # REQUIRED
    linked_at: str  # REQUIRED
    namespace: str  # REQUIRED
    origin_namespace: str  # REQUIRED
    user_id: str  # REQUIRED
    display_name: str  # OPTIONAL
    email_address: str  # OPTIONAL
    platform_id: str  # OPTIONAL
    platform_user_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_account_group(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.account_group = value
        return self

    def with_linked_at(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.linked_at = value
        return self

    def with_namespace(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.namespace = value
        return self

    def with_origin_namespace(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.origin_namespace = value
        return self

    def with_user_id(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.user_id = value
        return self

    def with_display_name(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.display_name = value
        return self

    def with_email_address(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.email_address = value
        return self

    def with_platform_id(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.platform_id = value
        return self

    def with_platform_user_id(self, value: str) -> AccountcommonUserLinkedPlatformV3:
        self.platform_user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "account_group"):
            result["accountGroup"] = str(self.account_group)
        elif include_empty:
            result["accountGroup"] = ""
        if hasattr(self, "linked_at"):
            result["linkedAt"] = str(self.linked_at)
        elif include_empty:
            result["linkedAt"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "origin_namespace"):
            result["originNamespace"] = str(self.origin_namespace)
        elif include_empty:
            result["originNamespace"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "display_name"):
            result["displayName"] = str(self.display_name)
        elif include_empty:
            result["displayName"] = ""
        if hasattr(self, "email_address"):
            result["emailAddress"] = str(self.email_address)
        elif include_empty:
            result["emailAddress"] = ""
        if hasattr(self, "platform_id"):
            result["platformId"] = str(self.platform_id)
        elif include_empty:
            result["platformId"] = ""
        if hasattr(self, "platform_user_id"):
            result["platformUserId"] = str(self.platform_user_id)
        elif include_empty:
            result["platformUserId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        account_group: str,
        linked_at: str,
        namespace: str,
        origin_namespace: str,
        user_id: str,
        display_name: Optional[str] = None,
        email_address: Optional[str] = None,
        platform_id: Optional[str] = None,
        platform_user_id: Optional[str] = None,
    ) -> AccountcommonUserLinkedPlatformV3:
        instance = cls()
        instance.account_group = account_group
        instance.linked_at = linked_at
        instance.namespace = namespace
        instance.origin_namespace = origin_namespace
        instance.user_id = user_id
        if display_name is not None:
            instance.display_name = display_name
        if email_address is not None:
            instance.email_address = email_address
        if platform_id is not None:
            instance.platform_id = platform_id
        if platform_user_id is not None:
            instance.platform_user_id = platform_user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AccountcommonUserLinkedPlatformV3:
        instance = cls()
        if not dict_:
            return instance
        if "accountGroup" in dict_ and dict_["accountGroup"] is not None:
            instance.account_group = str(dict_["accountGroup"])
        elif include_empty:
            instance.account_group = ""
        if "linkedAt" in dict_ and dict_["linkedAt"] is not None:
            instance.linked_at = str(dict_["linkedAt"])
        elif include_empty:
            instance.linked_at = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "originNamespace" in dict_ and dict_["originNamespace"] is not None:
            instance.origin_namespace = str(dict_["originNamespace"])
        elif include_empty:
            instance.origin_namespace = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "displayName" in dict_ and dict_["displayName"] is not None:
            instance.display_name = str(dict_["displayName"])
        elif include_empty:
            instance.display_name = ""
        if "emailAddress" in dict_ and dict_["emailAddress"] is not None:
            instance.email_address = str(dict_["emailAddress"])
        elif include_empty:
            instance.email_address = ""
        if "platformId" in dict_ and dict_["platformId"] is not None:
            instance.platform_id = str(dict_["platformId"])
        elif include_empty:
            instance.platform_id = ""
        if "platformUserId" in dict_ and dict_["platformUserId"] is not None:
            instance.platform_user_id = str(dict_["platformUserId"])
        elif include_empty:
            instance.platform_user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, AccountcommonUserLinkedPlatformV3]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[AccountcommonUserLinkedPlatformV3]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        AccountcommonUserLinkedPlatformV3,
        List[AccountcommonUserLinkedPlatformV3],
        Dict[Any, AccountcommonUserLinkedPlatformV3],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "accountGroup": "account_group",
            "linkedAt": "linked_at",
            "namespace": "namespace",
            "originNamespace": "origin_namespace",
            "userId": "user_id",
            "displayName": "display_name",
            "emailAddress": "email_address",
            "platformId": "platform_id",
            "platformUserId": "platform_user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "accountGroup": True,
            "linkedAt": True,
            "namespace": True,
            "originNamespace": True,
            "userId": True,
            "displayName": False,
            "emailAddress": False,
            "platformId": False,
            "platformUserId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Seasonpass Service."""

__version__ = "1.16.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_user_progression_request import BulkUserProgressionRequest
from .claimable_rewards import ClaimableRewards
from .claimable_user_season_info import ClaimableUserSeasonInfo
from .error_entity import ErrorEntity
from .excess_strategy import ExcessStrategy
from .excess_strategy import MethodEnum as ExcessStrategyMethodEnum
from .exp_grant_history_info import ExpGrantHistoryInfo
from .exp_grant_history_info import SourceEnum as ExpGrantHistoryInfoSourceEnum
from .exp_grant_history_paging_sliced_result import ExpGrantHistoryPagingSlicedResult
from .field_validation_error import FieldValidationError
from .full_season_info import FullSeasonInfo
from .image import Image
from .list_season_info import ListSeasonInfo
from .list_season_info import StatusEnum as ListSeasonInfoStatusEnum
from .list_season_info_paging_sliced_result import ListSeasonInfoPagingSlicedResult
from .list_user_season_info import ListUserSeasonInfo
from .list_user_season_info_paging_sliced_result import (
    ListUserSeasonInfoPagingSlicedResult,
)
from .localization import Localization
from .localized_pass_info import LocalizedPassInfo
from .localized_season_info import LocalizedSeasonInfo
from .localized_season_info import StatusEnum as LocalizedSeasonInfoStatusEnum
from .ownership import Ownership
from .paging import Paging
from .pass_create import PassCreate
from .pass_info import PassInfo
from .pass_update import PassUpdate
from .reason_tags_result import ReasonTagsResult
from .reward_create import RewardCreate
from .reward_create import TypeEnum as RewardCreateTypeEnum
from .reward_currency import RewardCurrency
from .reward_info import RewardInfo
from .reward_info import (
    ItemTypeEnum as RewardInfoItemTypeEnum,
    TypeEnum as RewardInfoTypeEnum,
)
from .reward_update import RewardUpdate
from .reward_update import TypeEnum as RewardUpdateTypeEnum
from .season_clone_request import SeasonCloneRequest
from .season_create import SeasonCreate
from .season_info import SeasonInfo
from .season_info import StatusEnum as SeasonInfoStatusEnum
from .season_summary import SeasonSummary
from .season_summary import StatusEnum as SeasonSummaryStatusEnum
from .season_update import SeasonUpdate
from .tier import Tier
from .tier_create import TierCreate
from .tier_input import TierInput
from .tier_paging_sliced_result import TierPagingSlicedResult
from .tier_reorder import TierReorder
from .user_exp_grant import UserExpGrant
from .user_exp_grant import SourceEnum as UserExpGrantSourceEnum
from .user_pass_grant import UserPassGrant
from .user_purchasable import UserPurchasable
from .user_reward_claim import UserRewardClaim
from .user_season_summary import UserSeasonSummary
from .user_tier_grant import UserTierGrant
from .user_tier_grant import SourceEnum as UserTierGrantSourceEnum
from .validation_error_entity import ValidationErrorEntity



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ModelsMultipleAgentType
from ..models import ModelsMultipleEventID
from ..models import ModelsMultipleEventLevel
from ..models import ModelsMultipleEventType
from ..models import ModelsMultipleUX

from ..operations.event_descriptions import AgentTypeDescriptionHandler
from ..operations.event_descriptions import EventIDDescriptionHandler
from ..operations.event_descriptions import EventLevelDescriptionHandler
from ..operations.event_descriptions import EventTypeDescriptionHandler
from ..operations.event_descriptions import SpecificAgentTypeDescriptionHandler
from ..operations.event_descriptions import SpecificEventIDDescriptionHandler
from ..operations.event_descriptions import SpecificEventLevelDescriptionHandler
from ..operations.event_descriptions import SpecificEventTypeDescriptionHandler
from ..operations.event_descriptions import SpecificUXDescriptionHandler
from ..operations.event_descriptions import UXNameDescriptionHandler


@deprecated
@same_doc_as(AgentTypeDescriptionHandler)
def agent_type_description_handler(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = AgentTypeDescriptionHandler.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AgentTypeDescriptionHandler)
async def agent_type_description_handler_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = AgentTypeDescriptionHandler.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(EventIDDescriptionHandler)
def event_id_description_handler(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventIDDescriptionHandler.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(EventIDDescriptionHandler)
async def event_id_description_handler_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventIDDescriptionHandler.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(EventLevelDescriptionHandler)
def event_level_description_handler(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventLevelDescriptionHandler.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(EventLevelDescriptionHandler)
async def event_level_description_handler_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventLevelDescriptionHandler.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(EventTypeDescriptionHandler)
def event_type_description_handler(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventTypeDescriptionHandler.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(EventTypeDescriptionHandler)
async def event_type_description_handler_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = EventTypeDescriptionHandler.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SpecificAgentTypeDescriptionHandler)
def specific_agent_type_description_handler(
    agent_types: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificAgentTypeDescriptionHandler.create(
        agent_types=agent_types,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SpecificAgentTypeDescriptionHandler)
async def specific_agent_type_description_handler_async(
    agent_types: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificAgentTypeDescriptionHandler.create(
        agent_types=agent_types,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SpecificEventIDDescriptionHandler)
def specific_event_id_description_handler(
    event_ids: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventIDDescriptionHandler.create(
        event_ids=event_ids,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SpecificEventIDDescriptionHandler)
async def specific_event_id_description_handler_async(
    event_ids: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventIDDescriptionHandler.create(
        event_ids=event_ids,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SpecificEventLevelDescriptionHandler)
def specific_event_level_description_handler(
    event_levels: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventLevelDescriptionHandler.create(
        event_levels=event_levels,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SpecificEventLevelDescriptionHandler)
async def specific_event_level_description_handler_async(
    event_levels: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventLevelDescriptionHandler.create(
        event_levels=event_levels,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SpecificEventTypeDescriptionHandler)
def specific_event_type_description_handler(
    event_types: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventTypeDescriptionHandler.create(
        event_types=event_types,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SpecificEventTypeDescriptionHandler)
async def specific_event_type_description_handler_async(
    event_types: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificEventTypeDescriptionHandler.create(
        event_types=event_types,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SpecificUXDescriptionHandler)
def specific_ux_description_handler(
    ux: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificUXDescriptionHandler.create(
        ux=ux,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SpecificUXDescriptionHandler)
async def specific_ux_description_handler_async(
    ux: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SpecificUXDescriptionHandler.create(
        ux=ux,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(UXNameDescriptionHandler)
def ux_name_description_handler(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = UXNameDescriptionHandler.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(UXNameDescriptionHandler)
async def ux_name_description_handler_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = UXNameDescriptionHandler.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
